############### Global environmental controls on wildfire burnt area, size, and intensity  ############

### script to get models 

#### Olivia Haas
#### Dr Iain Colin Prentice and Dr Sandy P. Harrisson 

## load libraries and functions
library(raster)
library(car)
library(stats)
library(caret)
library(visreg)
setwd("...")

## pseudo McFadden's R-squared
pr2 <- function(mod)(1-mod$deviance/mod$null.deviance)

## create raster 
creat.raster_0.5 <- function(lonlat,var)
  
{
  
  #r <- raster(nrow=360, ncol=720, ymn=-89.75, ymx=89.75, xmn=-179.75, xmx=179.75) 
  
  r <- raster(nrow=360, ncol=720, ymn=-90, ymx=90, xmn=-180, xmx=180) 
  
  Cells <- cellFromXY(r, lonlat)
  
  r[Cells] <- var
  
  return(r)
  
}



## open predictors data 
predictors <- brick("../predictors_revised.nc")
names(predictors)<- c("GPP","GPP_seasonality","shrub","grass","tree","crop","roads","VRM", "TPI", "DD","DD_seasonality","VPD","DTR","wind","light","popd")
## open fire data 
fire <- brick(".../fire_variables.nc")
names(fire) <- c("BA_mean","size_median","intensity_median","intensity")

### data frame for Burnt Area
ba_stack <- stack(fire[[1]], predictors)
## create spatial data frame for Burnt Area
llprj <-"+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs +towgs84=0,0,0"
spts <- rasterToPoints(ba_stack, spatial = TRUE)
llpts <- spTransform(spts, CRS(llprj))
ba_dat <- as.data.frame(llpts)




### data frame for Fire Size
size_stack <- stack(fire[[2]], predictors)
## create spatial data frame for Burnt Area
llprj <-"+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs +towgs84=0,0,0"
spts <- rasterToPoints(size_stack, spatial = TRUE)
llpts <- spTransform(spts, CRS(llprj))
size_dat <- as.data.frame(llpts)


### data frame for Intensity
intensity_stack <- stack(fire[[4]], predictors)
## create spatial data frame for Burnt Area
llprj <-"+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs +towgs84=0,0,0"
spts <- rasterToPoints(intensity_stack, spatial = TRUE)
llpts <- spTransform(spts, CRS(llprj))
intensity_dat <- as.data.frame(llpts)


## remove missing values for each fire variable 
ba_dat <- subset(ba_dat, !is.na(ba_dat$BA_mean)& !is.na(ba_dat$GPP)& !is.na(ba_dat$tree)& !is.na(ba_dat$shrub)& !is.na(ba_dat$grass)& !is.na(ba_dat$crop)& !is.na(ba_dat$roads)& !is.na(ba_dat$VPD)& !is.na(ba_dat$DD)& !is.na(ba_dat$DTR)& !is.na(ba_dat$wind)& !is.na(ba_dat$popd)& !is.na(ba_dat$light)& !is.na(ba_dat$VRM+TPI)&  !is.na(ba_dat$GPP_seasonality)&  !is.na(ba_dat$DD_seasonality))
size_dat <- subset(size_dat, !is.na(size_dat$size_median)& !is.na(size_dat$GPP)& !is.na(size_dat$tree)& !is.na(size_dat$shrub)& !is.na(size_dat$grass)& !is.na(size_dat$crop)& !is.na(size_dat$roads)& !is.na(size_dat$VPD)& !is.na(size_dat$DD)& !is.na(size_dat$DTR)& !is.na(size_dat$wind)& !is.na(size_dat$popd)& !is.na(size_dat$light)& !is.na(size_dat$VRM+TPI)&  !is.na(size_dat$GPP_seasonality)&  !is.na(size_dat$DD_seasonality))
intensity_dat <- subset(intensity_dat, !is.na(intensity_dat$intensity)& !is.na(intensity_dat$GPP)& !is.na(intensity_dat$tree)& !is.na(intensity_dat$shrub)& !is.na(intensity_dat$grass)& !is.na(intensity_dat$crop)& !is.na(intensity_dat$roads)& !is.na(intensity_dat$VPD)& !is.na(intensity_dat$DD)& !is.na(intensity_dat$DTR)& !is.na(intensity_dat$wind)& !is.na(intensity_dat$popd)& !is.na(intensity_dat$light)& !is.na(intensity_dat$VRM+TPI)&  !is.na(intensity_dat$GPP_seasonality)&  !is.na(intensity_dat$DD_seasonality))

## remove 0s for log transformation
ba_dat<-subset(ba_dat, !ba_dat$GPP==0)
size_dat<-subset(size_dat, !size_dat$GPP==0)
intensity_dat<-subset(intensity_dat, !intensity_dat$GPP==0)


## transformations
ba_dat$sqr_popd <- sqrt(ba_dat$popd)
ba_dat$sqr_light <- sqrt(ba_dat$light)
ba_dat$sqr_roads <- sqrt(ba_dat$roads)
ba_dat$sqr_roads <- sqrt(ba_dat$roads)
ba_dat$log_GPP <- log(ba_dat$GPP)
ba_dat$log_DTR <- log(ba_dat$DTR)
ba_dat$log_DD <- log(ba_dat$DD)
ba_dat$log_VPD <- log(ba_dat$VPD)
ba_dat$log_wind <- log(ba_dat$wind)
ba_dat$log_DD_season <- log(ba_dat$DD_seasonality)
ba_dat$log_GPP_season <- log(ba_dat$GPP_seasonality)

size_dat$sqr_popd <- sqrt(size_dat$popd)
size_dat$sqr_light <- sqrt(size_dat$light)
size_dat$sqr_roads <- sqrt(size_dat$roads)
size_dat$log_GPP <- log(size_dat$GPP)
size_dat$log_DTR <- log(size_dat$DTR)
size_dat$log_DD <- log(size_dat$DD)
size_dat$log_VPD <- log(size_dat$VPD)
size_dat$log_wind <- log(size_dat$wind)
size_dat$log_DD_season <- log(size_dat$DD_seasonality)
size_dat$log_GPP_season <- log(size_dat$GPP_seasonality)

intensity_dat$sqr_popd <- sqrt(intensity_dat$popd)
intensity_dat$sqr_light <- sqrt(intensity_dat$light)
intensity_dat$sqr_roads <- sqrt(intensity_dat$roads)
intensity_dat$log_GPP <- log(intensity_dat$GPP)
intensity_dat$log_DTR <- log(intensity_dat$DTR)
intensity_dat$log_DD <- log(intensity_dat$DD)
intensity_dat$log_VPD <- log(intensity_dat$VPD)
intensity_dat$log_wind <- log(intensity_dat$wind)
intensity_dat$log_DD_season <- log(intensity_dat$DD_seasonality)
intensity_dat$log_GPP_season <- log(intensity_dat$GPP_seasonality)

## get z scores
size_dat$z_scores<- abs((size_dat$size_median-mean(size_dat$size_median))/sd(size_dat$size_median))
intensity_dat$z_scores<- abs((intensity_dat$intensity-mean(intensity_dat$intensity))/sd(intensity_dat$intensity))

## exclude outliers
size_dat <- subset(size_dat, !size_dat$z_scores>3)
intensity_dat <- subset(intensity_dat, !intensity_dat$z_scores>3)

## normalize
size_dat$norm <- (size_dat$size_median-min(size_dat$size_median))/(max(size_dat$size_median)-min(size_dat$size_median))
intensity_dat$norm <- (intensity_dat$intensity-min(intensity_dat$intensity))/(max(intensity_dat$intensity)-min(intensity_dat$intensity))

### full models
glm_ba_full <- glm(BA_mean~log_GPP+log_GPP_season+tree+shrub+grass+sqr_roads+crop+VRM+TPI+log_DD+log_DD_season+log_VPD+log_DTR+log_wind+sqr_light+sqr_popd, family="quasibinomial", data=ba_dat)
glm_size_full <- glm(norm~log_GPP+log_GPP_season+tree+shrub+grass+sqr_roads+crop+VRM+TPI+log_DD+log_DD_season+log_VPD+log_DTR+log_wind+sqr_light+sqr_popd, family="quasipoisson", data=size_dat)
glm_intensity_full <- glm(norm~log_GPP+log_GPP_season+tree+shrub+grass+sqr_roads+crop+VRM+TPI+log_DD+log_DD_season+log_VPD+log_DTR+log_wind+sqr_light+sqr_popd, family="quasipoisson", data=intensity_dat)

vif_ba_full <- as.data.frame(vif(glm_ba_full))
vif_size_full <- as.data.frame(vif(glm_size_full))
vif_intensity_full <- as.data.frame(vif(glm_intensity_full))
### no roads
glm_ba_noroads <- glm(BA_mean~log_GPP+log_GPP_season+tree+shrub+grass+crop+VRM+TPI+log_DD+log_DD_season+log_VPD+log_DTR+log_wind+sqr_light+sqr_popd, family="quasibinomial", data=ba_dat)
glm_size_noroads <- glm(norm~log_GPP+log_GPP_season+tree+shrub+grass+crop+VRM+TPI+log_DD+log_DD_season+log_VPD+log_DTR+log_wind+sqr_light+sqr_popd, family="quasipoisson", data=size_dat)
glm_intensity_noroads <- glm(norm~log_GPP+log_GPP_season+tree+shrub+grass+crop+VRM+TPI+log_DD+log_DD_season+log_VPD+log_DTR+log_wind+sqr_light+sqr_popd, family="quasipoisson", data=intensity_dat)

vif_ba_noroads <- as.data.frame(vif(glm_ba_noroads))
vif_size_noroads <- as.data.frame(vif(glm_size_noroads))
vif_intensity_noroads <- as.data.frame(vif(glm_intensity_noroads))

### no popd
glm_ba_nopopd <- glm(BA_mean~log_GPP+log_GPP_season+tree+shrub+grass+sqr_roads+crop+VRM+TPI+log_DD+log_DD_season+log_VPD+log_DTR+log_wind+sqr_light, family="quasibinomial", data=ba_dat)
glm_size_nopopd <- glm(norm~log_GPP+log_GPP_season+tree+shrub+grass+sqr_roads+crop+VRM+TPI+log_DD+log_DD_season+log_VPD+log_DTR+log_wind+sqr_light, family="quasipoisson", data=size_dat)
glm_intensity_nopopd <- glm(norm~log_GPP+log_GPP_season+tree+shrub+grass+sqr_roads+crop+VRM+TPI+log_DD+log_DD_season+log_VPD+log_DTR+log_wind+sqr_light, family="quasipoisson", data=intensity_dat)

vif_ba_nopopd <- as.data.frame(vif(glm_ba_nopopd))
vif_size_nopopd <- as.data.frame(vif(glm_size_nopopd))
vif_intensity_nopopd <- as.data.frame(vif(glm_intensity_nopopd))

### no GPP season
glm_ba_nogpp <- glm(BA_mean~log_GPP+tree+shrub+grass+sqr_roads+crop+VRM+TPI+log_DD+log_DD_season+log_VPD+log_DTR+log_wind+sqr_light+sqr_popd, family="quasibinomial", data=ba_dat)
glm_size_nogpp <- glm(norm~log_GPP+tree+shrub+grass+sqr_roads+crop+VRM+TPI+log_DD+log_DD_season+log_VPD+log_DTR+log_wind+sqr_light+sqr_popd, family="quasipoisson", data=size_dat)
glm_intensity_nogpp <- glm(norm~log_GPP+tree+shrub+grass+sqr_roads+crop+VRM+TPI+log_DD+log_DD_season+log_VPD+log_DTR+log_wind+sqr_light+sqr_popd, family="quasipoisson", data=intensity_dat)

vif_ba_nogpp <- as.data.frame(vif(glm_ba_nogpp))
vif_size_nogpp <- as.data.frame(vif(glm_size_nogpp))
vif_intensity_nogpp <- as.data.frame(vif(glm_intensity_nogpp))

### no VPD
glm_ba_novpd <- glm(BA_mean~log_GPP+log_GPP_season+tree+shrub+grass+sqr_roads+crop+VRM+TPI+log_DD+log_DD_season+log_DTR+log_wind+sqr_light+sqr_popd, family="quasibinomial", data=ba_dat)
glm_size_novpd <- glm(norm~log_GPP+log_GPP_season+tree+shrub+grass+sqr_roads+crop+VRM+TPI+log_DD+log_DD_season+log_DTR+log_wind+sqr_light+sqr_popd, family="quasipoisson", data=size_dat)
glm_intensity_novpd <- glm(norm~log_GPP+log_GPP_season+tree+shrub+grass+sqr_roads+crop+VRM+TPI+log_DD+log_DD_season+log_DTR+log_wind+sqr_light+sqr_popd, family="quasipoisson", data=intensity_dat)

vif_ba_novpd <- as.data.frame(vif(glm_ba_novpd))
vif_size_novpd <- as.data.frame(vif(glm_size_novpd))
vif_intensity_novpd <- as.data.frame(vif(glm_intensity_novpd))